﻿#################
# Export-VMConfigOnly.ps1
# exports only a VM's configuration without the virtual hard disk files
# based on http://social.technet.microsoft.com/wiki/contents/articles/1350.hyper-v-export-vm-config-only-using-powershell.aspx
# Nils Kaczenski, faq-o-matic.net, 2016-12-21
#################

$SourceVM = Read-Host 'Specify the name of the VM to export'
$expDir = Read-Host 'Specify the target root path for the export (VM name will be appended)'

$ns = 'root\virtualization\v2'

$expDir = $expDir + $SourceVM
if( -Not (Test-Path -Path $expDir ) )
{
    New-Item -ItemType directory -Path $expDir | Out-Null
}
 
#Get VM Object
$vm = gwmi -n $ns Msvm_ComputerSystem | ?{$_.ElementName -eq $SourceVM} 
 
#Get export setting object
$exp = @($vm.GetRelated('Msvm_VirtualSystemExportSettingData'))[0]
 
#If you dont want to copy the VHDs and AVHDs
$exp.CopyVmStorage = $false
 
#If you dont want to copy the Saved state
$exp.CopyVmRuntimeInformation = $false
 
#Get VMMS object
$vmms = gwmi -n $ns Msvm_VirtualSystemManagementService
 
#Perform Export
$out = $vmms.ExportSystemDefinition($vm.Path.Path, $expDir, $exp.GetText(1))
 
#Perform Job handling if necessary
if ($out.ReturnValue -eq 4096)
{
       $task = [Wmi]$out.Job;
       while($task.JobState -eq 3 -or $task.JobState -eq 4)
       {
              $task.Get();
              sleep 1;
       }
       if ($task.JobState -ne 7)
       {
              "Error exporting VM " + $task.ErrorDescription;
       }            
       else
       {
              "Export completed successfully..."
       }     
      
}
elseif ($out.ReturnValue -ne 0)
{
       "Export failed with error : " + $out.ReturnValue;
}
else
{
       "Export completed successfully."
} 