﻿#############
# Import-VMFromTemplate.ps1
# Imports a VM by copying the original data and renaming the object afterwards
# thus, the original VM (which may have been exported) serves as a template
# if the export folder does not contain VHD or VHDX files all disks will be removed from the imported VM!
# Nils Kaczenski, faq-o-matic.net, 2016-12-21
#############

$SourceVM = Read-Host 'Enter the path of the source VM config file (XML or VMCX)'
$SourceVM = $SourceVM.Replace('"','') # remove quotes as Test-Path doesn't like them
if( -Not (Test-Path -PathType Leaf $SourceVM) )
{
    'File not found. Exiting script.'
    return
}

$TargetVMName = Read-Host 'Enter the name of the new VM to be created'
$TargetVMPath = Read-Host 'Enter the root path to store the new VM (VM name will be appended)'
$TargetVMPath = $TargetVMPath + '\' + $TargetVMName

# create the target folder if it does not exist
if( -Not (Test-Path -Path $TargetVMPath ) )
{
    New-Item -ItemType directory -Path $TargetVMPath | Out-Null
}


$NewVM = Import-VM -Path $SourceVM -Copy -VirtualMachinePath $TargetVMPath -GenerateNewId
Rename-VM $NewVM -NewName $TargetVMName
"VM imported as $NewVM"

# check if the export contains Virtual Hard Disks
$SourceVHDPath = (Get-Item $SourceVM).Directory.Parent.FullName + '\Virtual Hard Disks\*.vhd*'
if (!(Test-Path $SourceVHDPath)) { 
    # no, it does not - thus remove VHD bindings from the VM
    Get-VMHardDiskDrive $NewVM | Remove-VMHardDiskDrive
    'VM virtual hard disks have been removed as there were none in the export data.'
}

$NewVM | fl *

